{% load i18n static %}{% block structure %}<!-- base -->
{% endblock %}
<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    {% block viewport %}<meta name="viewport" content="width=device-width,initial-scale=1">{% endblock %}
    <meta name="renderer" content="webkit">
    <!-- analytics -->
{% include 'includes/analytics.html' %}
    <title>{% block title %}{{ title }}{% endblock %}</title>
    <link rel="apple-touch-icon" sizes="180x180" href="{% static 'apple-touch-icon.png' %}">
    <!-- 🌐 web 开始 -->
{% block web %}{% endblock %}
    <!-- 🌐 web 结束 -->
</body>

</html>
